aboutsummaryrefslogtreecommitdiffstats
path: root/library/Smarty/libs/sysplugins/smarty_internal_resource_string.php
diff options
context:
space:
mode:
Diffstat (limited to 'library/Smarty/libs/sysplugins/smarty_internal_resource_string.php')
-rw-r--r--library/Smarty/libs/sysplugins/smarty_internal_resource_string.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/library/Smarty/libs/sysplugins/smarty_internal_resource_string.php b/library/Smarty/libs/sysplugins/smarty_internal_resource_string.php
index bfa069974..75e99e6fb 100644
--- a/library/Smarty/libs/sysplugins/smarty_internal_resource_string.php
+++ b/library/Smarty/libs/sysplugins/smarty_internal_resource_string.php
@@ -73,11 +73,11 @@ class Smarty_Internal_Resource_String extends Smarty_Resource
*
* @param Smarty $smarty Smarty instance
* @param string $resource_name resource_name to make unique
* @param boolean $is_config flag for config resource
*
* @return string unique resource name
*/
- protected function buildUniqueResourceName(Smarty $smarty, $resource_name, $is_config = false)
+ public function buildUniqueResourceName(Smarty $smarty, $resource_name, $isConfig = false)
{
return get_class($this) . '#' . $this->decode($resource_name);
}
@@ -90,7 +90,7 @@ class Smarty_Internal_Resource_String extends Smarty_Resource
*
* @return string resource's basename
*/
- protected function getBasename(Smarty_Template_Source $source)
+ public function getBasename(Smarty_Template_Source $source)
{
return '';
}
@@ -73,11 +73,11 @@ class Smarty_Internal_Resource_String extends Smarty_Resource
* @param Smarty $smarty Smarty instance
* @param string $resource_name resource_name to make unique
- * @param boolean $is_config flag for config resource
+ * @param boolean $isConfig flag for config resource
*
* @return string unique resource name